@@ -35,7 +35,7 @@ def _split_arrays_function(name, value, offset=1, sparse_indexing=False):
 
     if isinstance(value, sparray):
         tmp = value.fortran_repr()
-        for off, sub_value in zip(list(tmp.keys()), list(tmp.values())):
+        for off, sub_value in zip(tmp.keys(), tmp.values()):
             if len(off):
                 N, V = _split_arrays_function(name, sub_value, eval(off), sparse_indexing=True)
                 names.extend(N)
@@ -149,7 +149,7 @@ def interpreter(orig, escaped_strings=True):
 
 def array_encoder(orig, line='', level=0, separator_arrays=' ', compress_arrays=True, max_array_chars=79, escaped_strings=True):
     all = line
-    tmps = list([encoder(orig, escaped_strings) for orig in np.atleast_1d(orig)])
+    tmps = [encoder(orig, escaped_strings) for orig in np.atleast_1d(orig)]
 
     # compress repeted entries
     if compress_arrays and len(tmps) > 0:
@@ -270,7 +270,7 @@ class NamelistName(SortedDict):
         dimensions.update(self.collect_arrays)
 
         # find the arrays to collect
-        for kid in list(self.keys()):
+        for kid in self.keys():
             if isinstance(self[kid], NamelistName):
                 self[kid].collect_arrays = self.collect_arrays
                 self[kid].collectArrays(dimensions, **input_dimensions)
@@ -284,7 +284,7 @@ class NamelistName(SortedDict):
                 collect.setdefault(var, [])
 
         # expand ranges
-        for kid in list(self.keys()):
+        for kid in self.keys():
             mat = re.match(r'(.*)\((.*)\)', kid)
             if not mat:
                 continue
@@ -317,7 +317,7 @@ class NamelistName(SortedDict):
 
             rngs = list(map(int, ranks[rng_ri].split(':')))
             rngs[1] = rngs[1] + 1
-            if len(list(range(*rngs))) != len(self[kid]):
+            if len(range(*rngs)) != len(self[kid]):
                 raise ValueError('Length of range and values disagree for %s: %s; %s' % (kid, ranks[rng_ri], self[kid]))
             for ri, rang in enumerate(range(*rngs)):
                 self[new_key.format(prefix=prefix, var=var, rg_ind=rang, postfix=postfix)] = self[kid][ri]
@@ -325,7 +325,7 @@ class NamelistName(SortedDict):
 
         # find the arrays to collect
         warn_msg = []
-        for kid in list(self.keys()):
+        for kid in self.keys():
             if (
                 re.sub(r'(.*)\((.*)\)', r'\1', kid) in collect
                 or kid in self.collect_arrays
@@ -370,7 +370,7 @@ class NamelistName(SortedDict):
                 collect[var].append(indexStr)
 
         # user defined shapes
-        for var in list(collect.keys()):
+        for var in collect.keys():
             if var in dimensions and 'shape' in dimensions[var]:
                 shapes[var] = tuple(dimensions[var]['shape'])
             else:
@@ -379,7 +379,7 @@ class NamelistName(SortedDict):
         # if there is something to collect
         if len(collect):
             # if there was a default as array update the offsets to be at maximum 1
-            for var in list(collect.keys()):
+            for var in collect.keys():
                 for k, indexStr in enumerate(collect[var]):
                     if indexStr is None:
                         if len(collect[var]) > 1 or offsets[var] != 0:
@@ -391,7 +391,7 @@ class NamelistName(SortedDict):
                             continue
 
             # user defined offsets
-            for var in list(offsets.keys()):
+            for var in offsets.keys():
                 if var in dimensions and 'offset' in dimensions[var]:
                     offsets[var] = tuple(dimensions[var]['offset'])
                 elif '__offset__' in dimensions:
@@ -401,17 +401,17 @@ class NamelistName(SortedDict):
                     offsets[var] = tuple([min(offsets[var])] * len(offsets[var]))
 
             # defaults
-            for var in list(offsets.keys()):
+            for var in offsets.keys():
                 if isinstance(dtypes[var], str):
                     defaults[var] = dimensions.get('__default__', '')
                 else:
                     defaults[var] = dimensions.get('__default__', np.nan)
-            for var in list(offsets.keys()):
+            for var in offsets.keys():
                 if var in dimensions and 'default' in dimensions[var]:
                     defaults[var] = dimensions[var]['default']
 
             # define sparse arrays
-            for var in list(offsets.keys()):
+            for var in offsets.keys():
 
                 # handle arrays of strings
                 if isinstance(dtypes[var], str):
@@ -476,7 +476,7 @@ class NamelistName(SortedDict):
 
     def collect(self, value):
         self._collect = value
-        for kid in list(self.keys()):
+        for kid in self.keys():
             if isinstance(self[kid], NamelistName):
                 self[kid].collect(value)
 
@@ -491,16 +491,14 @@ class NamelistName(SortedDict):
         key = self._keyCaseInsensitive(key)
 
         # handle internal key indexing
-        if key not in list(self.keys()) and re.match(r'.*\(.*\)', key):
+        if '(' in key and re.match(r'.*\(.*\)', key) and key not in self.keys():
             index = np.array(list(map(int, re.sub(r'(.*)\((.*)\)', r'\2', key).split(','))))
             key = re.sub(r'(.*)\((.*)\)', r'\1', key)
         else:
             index = None
 
-        try:
-            tmp = super().__getitem__(key)
-        except KeyError:
-            raise
+        # get the value
+        tmp = super().__getitem__(key)
 
         # return (indexed) object
         if index is None or not len(np.shape(tmp)):
@@ -739,7 +737,7 @@ class NamelistFile(NamelistName):
 
             if c == '\n':
                 # if it's a new line, then it's a new record and all rules should be reset
-                for key in list(rules.keys()):
+                for key in rules.keys():
                     rules[key] = 0
 
             # handle comments outside of namelist
@@ -774,7 +772,7 @@ class NamelistFile(NamelistName):
             if inside or not self.outsideOfNamelistIsComment:
 
                 # this is a new item
-                if (c in ' \t,=' and not np.any([rules[key] for key in list(rules.keys())])) or c == '\n':
+                if (c in ' \t,=' and not np.any([rules[key] for key in rules.keys()])) or c == '\n':
                     if item_length > 0:
                         item = item_prepend + tmpj[item_offset : item_offset + item_length]
                         item_offset += item_length
@@ -787,29 +785,27 @@ class NamelistFile(NamelistName):
 
                 # this is the continuation of the current item
                 else:
-                    if c == '(' and not np.any([rules[key] for key in list(rules.keys()) if key != 'round_bracket']):
+                    if c == '(' and not np.any([rules[key] for key in rules.keys() if key != 'round_bracket']):
                         rules['round_bracket'] += 1
-                    elif c == ')' and not np.any([rules[key] for key in list(rules.keys()) if key != 'round_bracket']):
+                    elif c == ')' and not np.any([rules[key] for key in rules.keys() if key != 'round_bracket']):
                         rules['round_bracket'] -= 1
-                    elif c == "'" and not np.any([rules[key] for key in list(rules.keys()) if key != 'single']):
+                    elif c == "'" and not np.any([rules[key] for key in rules.keys() if key != 'single']):
                         rules['single'] = (rules['single'] + 1) % 2
-                    elif c == '"' and not np.any([rules[key] for key in list(rules.keys()) if key != 'double']):
+                    elif c == '"' and not np.any([rules[key] for key in rules.keys() if key != 'double']):
                         rules['double'] = (rules['double'] + 1) % 2
-                    elif (c in self.bang_comment_symbol) and not np.any(
-                        [rules[key] for key in list(rules.keys()) if key != 'bang_comment']
-                    ):
+                    elif (c in self.bang_comment_symbol) and not np.any([rules[key] for key in rules.keys() if key != 'bang_comment']):
                         rules['bang_comment'] = 1
                     elif (
                         (self.nospaceIsComment and not self.outsideOfNamelistIsComment)
                         and (cm == '\n' and c not in ' \t')
-                        and not np.any([rules[key] for key in list(rules.keys()) if key != 'line_comment'])
+                        and not np.any([rules[key] for key in rules.keys() if key != 'line_comment'])
                     ):
                         rules['line_comment'] = 1
                         item_prepend = u'\1'
 
                 # when namelist block ends
                 if self.outsideOfNamelistIsComment:
-                    if inside and not np.any([rules[key] for key in list(rules.keys())]) and ((cm == '/' and c == '\n')):
+                    if inside and not np.any([rules[key] for key in rules.keys()]) and ((cm == '/' and c == '\n')):
                         inside -= 1
                         # if namelist block ends and last item had / then
                         # reasonable to assume that / was the termination
@@ -893,9 +889,9 @@ class NamelistFile(NamelistName):
 
         # now interpret the list of stings
         def i_traverse(me):
-            if '__parent__' in list(me.keys()):
+            if '__parent__' in me.keys():
                 del me['__parent__']
-            for kid in list(me.keys()):
+            for kid in me.keys():
                 if isinstance(me[kid], dict):
                     i_traverse(me[kid])
                 elif not re.match(comment_ptrn, kid):
@@ -958,7 +954,7 @@ class NamelistFile(NamelistName):
             f = open(self.filename, 'w+')
 
         def f_traverse(me, level):
-            for kid in list(me.keys()):
+            for kid in me.keys():
                 if _debug():
                     print('Writing ', kid)
                 if isinstance_str(me[kid], ['OMFITexpression', 'OMFITiterableExpression']):
@@ -997,7 +993,7 @@ class NamelistFile(NamelistName):
                         for kid, meKid in zip(kid0, meKid0):
                             if isinstance(meKid, sparray):
                                 tmp = meKid.fortran_repr()
-                                for item, value in zip(list(tmp.keys()), list(tmp.values())):
+                                for item, value in zip(tmp.keys(), tmp.values()):
                                     line = ' ' * level + kid + item + self._equals
                                     if self.idlInput:
                                         line += '['
@@ -1253,7 +1249,7 @@ class sparray(object):
     def fortran_repr(self):
         # print strips
         strips = OrderedDict()
-        for item in list(self.__data.keys()):
+        for item in self.__data.keys():
             item = tuple(item)
             strips.setdefault(item[1:], item)
             strips[item[1:]] = tuple(map(int, np.min([strips[item[1:]], item], 0)))
@@ -1263,7 +1259,7 @@ class sparray(object):
         if not self.isnan(self.default):
             outputs[''] = self.default
 
-        for item in list(strips.values()):
+        for item in strips.values():
             tmp = list(item)
             tmp[0] = slice(None)
             tmp = tuple(tmp)
@@ -1312,7 +1308,7 @@ class sparray(object):
     def __str__(self):
         tmp = self.fortran_repr()
         out = []
-        for item, value in zip(list(tmp.keys()), list(tmp.values())):
+        for item, value in zip(tmp.keys(), tmp.values()):
             out.append('%s: %s' % (str(item)[1:-1], str(value)))
         return '\n'.join(out)
 
