@@ -1087,8 +1087,9 @@ class OMFIToedgeNC(OMFITnc):
         # get figure layout for number of plots on the page
         nrows, ncols = self.calculate_layout(nplts)
 
+        pyplot.figure(num=fig.number)
         for cnt in range(len(plot_list)):
-            ax = fig.add_subplot(nrows, ncols, cnt + 1)
+            ax = pyplot.subplot(nrows, ncols, cnt + 1)
             dataname, targname, label, scalef = self.get_names(plot_select, plot_list[cnt])
 
             if plot_type == 'contour-polygon':
@@ -1099,8 +1100,8 @@ class OMFIToedgeNC(OMFITnc):
             elif plot_type == 'contour-interpolate':
                 self.plot_contour_interpolate(fig, ax, dataname, targname, charge, zoom, scalef=scalef)
                 ax.set_title(label)
-            # set the figure title
-            fig.suptitle(plot_select)
+        # set the figure title
+        fig.suptitle(plot_select)
 
     def plot_contour_polygon(self, fig, ax, dataname, charge=None, zoom=None, scalef=1.0):
         # polygon plots never use the target data
@@ -1325,8 +1326,9 @@ class OMFIToedgeNC(OMFITnc):
 
         nrows, ncols = self.calculate_layout(nplts)
 
+        pyplot.figure(num=fig.number)
         for cnt in range(len(plot_list)):
-            ax = fig.add_subplot(nrows, ncols, cnt + 1)
+            ax = pyplot.subplot(nrows, ncols, cnt + 1)
             if len(charge_range) == 0:
                 dataname, targname, label, scalef = self.get_names(plot_select, plot_list[cnt])
                 axis, x_label = self.get_axis(ir_ref, axis_type, targname)
