@@ -286,8 +286,25 @@ class OMFITuFile(SortedDict, OMFITascii):
             axes.set_xlabel('Time $[s]$')
             axes.set_ylabel('Power $[MW]$')
             axes.set_title('Neutral beams power from ' + os.path.split(self.filename)[1])
-            leg = axes.legend(loc=0).draggable(True)
-
+            leg = axes.legend(loc=0, frameon=False).draggable(True)
+            # Additional info about the voltage, and current fractions
+            fig_beam_quants, ax_beam_quants = pyplot.subplots(nrows=4, sharex=True)
+            beams = OMFIT['TRANSP']['UFILES']['NBI']['BEAMS']
+            first_plot_lines = []
+            quants = [('power [MW]', 1e-6), ('voltage [kV]', 1e-3), ('full frac', 1), ('half frac', 1)]
+            for ind, beam in enumerate(self['BEAMS']):
+                for jj, (name, mult) in enumerate(quants):
+                    cur_ind = jj * len(self['BEAMS']) + ind
+                    ll = ax_beam_quants[jj].plot(self['X0']['data'], self['F']['data'][:, cur_ind] * mult, label=beam)
+                    if ind == 0:
+                        ax_beam_quants[jj].set_ylabel(name)
+                    if jj == 0:
+                        first_plot_lines.append(ll)
+            ax_beam_quants[-1].set_xlabel('Time [s]')
+            # ax_beam_quants[0].legend(loc='best',frameon=False)
+            ax_beam_quants[0].set_title('Neutral beams power from ' + os.path.split(self.filename)[1])
+            fig_beam_quants.legend(first_plot_lines, labels=self['BEAMS'], loc='upper right', frameon=False)
+            fig_beam_quants.subplots_adjust(right=0.8)
             for line in self['COMMENTS']:
                 if 'tilt' in line:
                     printi(line)
